#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gio
version:                2.0.38
visibility:             public
id:                     gi-gio-2.0.38-9KOwqPXPTu7JO1sOALIw31
key:                    gi-gio-2.0.38-9KOwqPXPTu7JO1sOALIw31
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Gio bindings
description:            Bindings for Gio, autogenerated by haskell-gi.
category:               Bindings
abi:                    8ccfecf8faf1398a056777ddd30f70e2
exposed:                True
exposed-modules:
    GI.Gio GI.Gio.Callbacks GI.Gio.Config GI.Gio.Constants GI.Gio.Enums
    GI.Gio.Flags GI.Gio.Functions GI.Gio.Interfaces
    GI.Gio.Interfaces.Action GI.Gio.Interfaces.ActionGroup
    GI.Gio.Interfaces.ActionMap GI.Gio.Interfaces.AppInfo
    GI.Gio.Interfaces.AsyncInitable GI.Gio.Interfaces.AsyncResult
    GI.Gio.Interfaces.Converter GI.Gio.Interfaces.DBusInterface
    GI.Gio.Interfaces.DBusObject GI.Gio.Interfaces.DBusObjectManager
    GI.Gio.Interfaces.DatagramBased GI.Gio.Interfaces.DebugController
    GI.Gio.Interfaces.Drive GI.Gio.Interfaces.DtlsClientConnection
    GI.Gio.Interfaces.DtlsConnection
    GI.Gio.Interfaces.DtlsServerConnection GI.Gio.Interfaces.File
    GI.Gio.Interfaces.Icon GI.Gio.Interfaces.Initable
    GI.Gio.Interfaces.ListModel GI.Gio.Interfaces.LoadableIcon
    GI.Gio.Interfaces.MemoryMonitor GI.Gio.Interfaces.Mount
    GI.Gio.Interfaces.NetworkMonitor
    GI.Gio.Interfaces.PollableInputStream
    GI.Gio.Interfaces.PollableOutputStream
    GI.Gio.Interfaces.PowerProfileMonitor GI.Gio.Interfaces.Proxy
    GI.Gio.Interfaces.ProxyResolver GI.Gio.Interfaces.RemoteActionGroup
    GI.Gio.Interfaces.Seekable GI.Gio.Interfaces.SocketConnectable
    GI.Gio.Interfaces.TlsBackend GI.Gio.Interfaces.TlsClientConnection
    GI.Gio.Interfaces.TlsFileDatabase
    GI.Gio.Interfaces.TlsServerConnection GI.Gio.Interfaces.Volume
    GI.Gio.Objects GI.Gio.Objects.AppInfoMonitor
    GI.Gio.Objects.AppLaunchContext GI.Gio.Objects.Application
    GI.Gio.Objects.ApplicationCommandLine
    GI.Gio.Objects.BufferedInputStream
    GI.Gio.Objects.BufferedOutputStream GI.Gio.Objects.BytesIcon
    GI.Gio.Objects.Cancellable GI.Gio.Objects.CharsetConverter
    GI.Gio.Objects.ConverterInputStream
    GI.Gio.Objects.ConverterOutputStream GI.Gio.Objects.Credentials
    GI.Gio.Objects.DBusActionGroup GI.Gio.Objects.DBusAuthObserver
    GI.Gio.Objects.DBusConnection GI.Gio.Objects.DBusInterfaceSkeleton
    GI.Gio.Objects.DBusMenuModel GI.Gio.Objects.DBusMessage
    GI.Gio.Objects.DBusMethodInvocation
    GI.Gio.Objects.DBusObjectManagerClient
    GI.Gio.Objects.DBusObjectManagerServer
    GI.Gio.Objects.DBusObjectProxy GI.Gio.Objects.DBusObjectSkeleton
    GI.Gio.Objects.DBusProxy GI.Gio.Objects.DBusServer
    GI.Gio.Objects.DataInputStream GI.Gio.Objects.DataOutputStream
    GI.Gio.Objects.DebugControllerDBus GI.Gio.Objects.Emblem
    GI.Gio.Objects.EmblemedIcon GI.Gio.Objects.FileEnumerator
    GI.Gio.Objects.FileIOStream GI.Gio.Objects.FileIcon
    GI.Gio.Objects.FileInfo GI.Gio.Objects.FileInputStream
    GI.Gio.Objects.FileMonitor GI.Gio.Objects.FileOutputStream
    GI.Gio.Objects.FilenameCompleter GI.Gio.Objects.FilterInputStream
    GI.Gio.Objects.FilterOutputStream GI.Gio.Objects.IOStream
    GI.Gio.Objects.IPTosMessage GI.Gio.Objects.IPv6TclassMessage
    GI.Gio.Objects.InetAddress GI.Gio.Objects.InetAddressMask
    GI.Gio.Objects.InetSocketAddress GI.Gio.Objects.InputStream
    GI.Gio.Objects.ListStore GI.Gio.Objects.MemoryInputStream
    GI.Gio.Objects.MemoryOutputStream GI.Gio.Objects.Menu
    GI.Gio.Objects.MenuAttributeIter GI.Gio.Objects.MenuItem
    GI.Gio.Objects.MenuLinkIter GI.Gio.Objects.MenuModel
    GI.Gio.Objects.MountOperation GI.Gio.Objects.NativeSocketAddress
    GI.Gio.Objects.NativeVolumeMonitor GI.Gio.Objects.NetworkAddress
    GI.Gio.Objects.NetworkService GI.Gio.Objects.Notification
    GI.Gio.Objects.OutputStream GI.Gio.Objects.Permission
    GI.Gio.Objects.PropertyAction GI.Gio.Objects.ProxyAddress
    GI.Gio.Objects.ProxyAddressEnumerator GI.Gio.Objects.Resolver
    GI.Gio.Objects.Settings GI.Gio.Objects.SettingsBackend
    GI.Gio.Objects.SimpleAction GI.Gio.Objects.SimpleActionGroup
    GI.Gio.Objects.SimpleAsyncResult GI.Gio.Objects.SimpleIOStream
    GI.Gio.Objects.SimplePermission GI.Gio.Objects.SimpleProxyResolver
    GI.Gio.Objects.Socket GI.Gio.Objects.SocketAddress
    GI.Gio.Objects.SocketAddressEnumerator GI.Gio.Objects.SocketClient
    GI.Gio.Objects.SocketConnection GI.Gio.Objects.SocketControlMessage
    GI.Gio.Objects.SocketListener GI.Gio.Objects.SocketService
    GI.Gio.Objects.Subprocess GI.Gio.Objects.SubprocessLauncher
    GI.Gio.Objects.Task GI.Gio.Objects.TcpConnection
    GI.Gio.Objects.TcpWrapperConnection GI.Gio.Objects.TestDBus
    GI.Gio.Objects.ThemedIcon GI.Gio.Objects.ThreadedResolver
    GI.Gio.Objects.ThreadedSocketService GI.Gio.Objects.TlsCertificate
    GI.Gio.Objects.TlsConnection GI.Gio.Objects.TlsDatabase
    GI.Gio.Objects.TlsInteraction GI.Gio.Objects.TlsPassword
    GI.Gio.Objects.UnixConnection GI.Gio.Objects.UnixCredentialsMessage
    GI.Gio.Objects.UnixFDList GI.Gio.Objects.UnixSocketAddress
    GI.Gio.Objects.Vfs GI.Gio.Objects.VolumeMonitor
    GI.Gio.Objects.ZlibCompressor GI.Gio.Objects.ZlibDecompressor
    GI.Gio.Structs GI.Gio.Structs.ActionEntry
    GI.Gio.Structs.DBusAnnotationInfo GI.Gio.Structs.DBusArgInfo
    GI.Gio.Structs.DBusErrorEntry GI.Gio.Structs.DBusInterfaceInfo
    GI.Gio.Structs.DBusInterfaceVTable GI.Gio.Structs.DBusMethodInfo
    GI.Gio.Structs.DBusNodeInfo GI.Gio.Structs.DBusPropertyInfo
    GI.Gio.Structs.DBusSignalInfo GI.Gio.Structs.DBusSubtreeVTable
    GI.Gio.Structs.FileAttributeInfo
    GI.Gio.Structs.FileAttributeInfoList
    GI.Gio.Structs.FileAttributeMatcher GI.Gio.Structs.IOExtension
    GI.Gio.Structs.IOExtensionPoint GI.Gio.Structs.IOModuleScope
    GI.Gio.Structs.IOSchedulerJob GI.Gio.Structs.IOStreamAdapter
    GI.Gio.Structs.InputMessage GI.Gio.Structs.InputStreamClass
    GI.Gio.Structs.InputVector GI.Gio.Structs.OutputMessage
    GI.Gio.Structs.OutputVector GI.Gio.Structs.Resource
    GI.Gio.Structs.SeekableIface GI.Gio.Structs.SettingsSchema
    GI.Gio.Structs.SettingsSchemaKey
    GI.Gio.Structs.SettingsSchemaSource GI.Gio.Structs.SrvTarget
    GI.Gio.Structs.StaticResource

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gio-2.0.38
library-dirs:           /usr/lib/ghc-9.6.6/site-local/gi-gio-2.0.38 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/gi-gio-2.0.38 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gio
hs-libraries:           HSgi-gio-2.0.38-9KOwqPXPTu7JO1sOALIw31
extra-libraries:        gio-2.0 gobject-2.0 glib-2.0
extra-libraries-static:
    gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 atomic m pcre2-8
    pthread z mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-glib-2.0.30-BSWCX0TespoEa7Obl1AiTt
    gi-gobject-2.0.31-CmykXXBP7sp9reN3vRdf0J
    haskell-gi-0.26.17-5ChzDzvktsV6dPlKtq3FgN
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-gio/html/gi-gio.haddock
haddock-html:           /usr/share/doc/haskell-gi-gio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

